@@ -1,5 +1,5 @@
 from unittest import TestCase
-from unittest.mock import patch
+from unittest.mock import Mock, patch
 
 from command_handler.request.validator import ValidatorFactory
 from command_handler.request.validator.asserts import command, json, privateIp
@@ -26,3 +26,22 @@ class ValidatorFactoryTest(TestCase):
         self.assertIn(command, asserts)
         self.assertIn(json, asserts)
         self.assertIn(privateIp, asserts)
+
+    def testCreateReturnsValidatorObjectWithMatchingAddedAsserts(self):
+        foo = Mock()
+        bar = Mock()
+
+        ValidatorFactory.addAssert("foo", foo)
+        ValidatorFactory.addAssert("bar", bar)
+
+        with patch("command_handler.request.validator.factory.Validator") as ValidatorPatch:
+            ValidatorFactory.create([
+                "foo",
+                "bar",
+            ])
+
+        args, kwargs = ValidatorPatch.call_args
+        asserts = kwargs.get("asserts") if "asserts" in kwargs else args[0]
+
+        self.assertIn(foo, asserts)
+        self.assertIn(bar, asserts)
